+++
title = "HUGO_SECTION set in post subtree"
description = "Test where `EXPORT_HUGO_SECTION` is set in the post subtree itself."
tags = ["section"]
draft = false
+++

This post will be created in the `zoo` section.
